package main

import (
	"fmt"
	"io/ioutil"
	"log"
	"net/http"
	"text/template"

	"gopkg.in/yaml.v3"
)

// Config types
// ------------
type ServerConfig struct {
	Name     string
	Homepage string
}
type AdminConfig struct {
	WebRoot string
	Port    int
	LogPath string
}
type AuthConfig struct {
	GiteaURL        string
	AuthorizedUsers []string
}
type Config struct {
	Server ServerConfig
	Admin  AdminConfig
	Auth   AuthConfig
}

var config = new(Config)

func loadConfig() (err error) {
	configfile, err := ioutil.ReadFile("config.yml")
	if err != nil {
		return err
	}

	err = yaml.Unmarshal(configfile, &config)
	return err
}

func handler(w http.ResponseWriter, r *http.Request) {
	path := r.URL.Path
	var tmpl string
	if path == "/" {
		tmpl = "templates/home.html"
	} else {
		tmpl = fmt.Sprintf("templates/%s", path)
	}
	t, _ := template.ParseFiles(tmpl)
	t.Execute(w, config)
}

func main() {
	err := loadConfig()
	fmt.Print(config)

	if err != nil {
		log.Fatalf("couldn't load config: %s", err)
	}

	http.Handle("/resources/",
		http.StripPrefix("/resources/",
			http.FileServer(http.Dir("./resources"))))

	http.HandleFunc("/", handler)

	err = http.ListenAndServe(":8080", nil)
	if err != nil {
		log.Fatal(err)
	}

}
